@@ -341,7 +341,7 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding) {
       "  (<path type='char') print",
       "  ( id=') print convertToR /id get str cvs print (') print",
       # Insert MARKS here so that postProcess() can easily locate strings
-      "  ( char='###TEXT) print 4 index print (###TEXT'>\n) print",
+      "  ( char='###TEXT) print 4 index print (###TEXT' >\n) print",
       "  pathforall",
       "  (\t<context>\n) print",
       "  printcol",
@@ -932,6 +932,32 @@ PScaptureFoot <-
       "%% EOF\n"
       )
 
+# Handle a "stringLine" that contains a NUL character
+# ONE LINE ONLY at a time
+processNUL <- function(filename, linenum) {
+    if (length(linenum) != 1)
+        stop("Bad computer!")
+    # Read in each piece of the element
+    bits <- scan(filename, skip=linenum - 1, nlines=1, quote=NULL,
+                 sep=" ", quiet=TRUE, what="character")
+    # The
+    #   string='###TEXT blah blah ###TEXT'
+    # part will be incomplete (terminated by the NUL char in blah blah)
+    # Replace
+    #   string='###TEXT whatever
+    # with
+    #   string=''
+    bits[grep("string='###TEXT", bits)] <-
+        paste(bits[grep("string='###TEXT", bits)], "###TEXT'", sep="")
+    # OR could be
+    #   char='###TEXT^@###TEXT'
+    bits[grep("char='###TEXT", bits)] <- "char='###TEXT###TEXT'"
+    # Check for ###TEXT' too
+    bits[grep("###TEXT' $", bits)] <- " "
+    # Put it all back together
+    paste(bits, collapse=" ")
+}
+
 # Perform some post-processing of the XML file that is generated by the
 # above PostScript code.
 # (e.g., do some character escaping that would be more painful to do
@@ -954,6 +980,14 @@ postProcess <- function(outfilename, enc) {
     # All string values have been marked 
     stringLines <- grep("###TEXT", lines)
     if (length(stringLines) > 0) {
+        # Check first for NUL-terminated text
+        # Test is no tag terminator, ">", at end of line
+        nulTerminated <- !grepl(">$", lines[stringLines])
+        if (any(nulTerminated)) {
+            for (i in stringLines[nulTerminated]) {
+                lines[i] <- processNUL(outfilename, i)
+            }
+        }
         stringLinesBits <- strsplit(lines[stringLines], "###TEXT")
         stringLinesMod <- sapply(stringLinesBits, processStringLine)
         lines[stringLines] <- stringLinesMod
